summaryrefslogtreecommitdiff
path: root/spec/commands
diff options
context:
space:
mode:
authorThe Bundler Bot <bot@bundler.io>2017-05-03 15:56:49 +0000
committerThe Bundler Bot <bot@bundler.io>2017-05-03 15:56:49 +0000
commitd085451947d41a0a3cdde3fd28723e11b842db7c (patch)
tree0c6b0ce9d82b674b5102c75c1f463e8d6cdf2492 /spec/commands
parentaf277266db3fac8c0dd52c8bb0bd2ba63ae78131 (diff)
parentf5193c0f62eb56555e1ad41e8707b1051137ea08 (diff)
downloadbundler-d085451947d41a0a3cdde3fd28723e11b842db7c.tar.gz
Auto merge of #5636 - koic:fix_typos, r=segiddins
Fix a typos I picked up a typical typos using [misspell](https://github.com/client9/misspell) and applied it.
Diffstat (limited to 'spec/commands')
-rw-r--r--spec/commands/config_spec.rb2
-rw-r--r--spec/commands/newgem_spec.rb4
-rw-r--r--spec/commands/update_spec.rb2
3 files changed, 4 insertions, 4 deletions
diff --git a/spec/commands/config_spec.rb b/spec/commands/config_spec.rb
index a3ca696ec1..4f4593fc24 100644
--- a/spec/commands/config_spec.rb
+++ b/spec/commands/config_spec.rb
@@ -267,7 +267,7 @@ RSpec.describe ".bundle/config" do
expect(out).to eq "bar=value"
end
- it "preferes local config over global" do
+ it "prefers local config over global" do
bundle "config --local bar value2"
bundle "config --global bar value"
bundle "config bar --parseable"
diff --git a/spec/commands/update_spec.rb b/spec/commands/update_spec.rb
index 4992e428da..41a2b38077 100644
--- a/spec/commands/update_spec.rb
+++ b/spec/commands/update_spec.rb
@@ -118,7 +118,7 @@ RSpec.describe "bundle update" do
end
describe "with --group option" do
- it "should update only specifed group gems" do
+ it "should update only specified group gems" do
install_gemfile <<-G
source "file://#{gem_repo2}"
gem "activesupport", :group => :development
diff --git a/spec/commands/newgem_spec.rb b/spec/commands/newgem_spec.rb
index a3c3a36419..c335bd4375 100644
--- a/spec/commands/newgem_spec.rb
+++ b/spec/commands/newgem_spec.rb
@@ -166,10 +166,10 @@ RSpec.describe "bundle gem" do
expect(bundled_app("test_gem/.git")).to exist
end
- context "when git is not avaiable" do
+ context "when git is not available" do
let(:gem_name) { "test_gem" }
# This spec cannot have `git` avaiable in the test env
before do
bundle_bin = File.expand_path("../../../exe/bundle", __FILE__)
load_paths = [lib, spec]
@@ -166,10 +166,10 @@ RSpec.describe "bundle gem" do
let(:gem_name) { "test_gem" }
- # This spec cannot have `git` avaiable in the test env
+ # This spec cannot have `git` available in the test env
before do
bundle_bin = File.expand_path("../../../exe/bundle", __FILE__)